Welcome to covmats's documentation!
===================================

.. include:: readme.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   api_reference
   usage
   contributing
   bibliography
   changelog
   authors

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
